function [handle] = eventFcn(obj)
% eventFcn - returns the handle of the event function for a location
%
% Syntax:  
%    [handle] = eventFcn(obj)
%
% Inputs:
%    obj - location object
%
% Outputs:
%    handle - event function handle
%
% Example: 
%
% Other m-files required: eventFcn
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author:       Matthias Althoff
% Written:      07-May-2007 
% Last update:  06-June-2011
% Last revision:---

%------------- BEGIN CODE --------------

%standard syntax for event functions as needed in Matlab simulations
function [value,isterminal,direction] = f(t,x)
    %get result of invariant events
	[value,isterminal,direction] = eventFcn(obj.invariant,x,1);
    %retrieve system dimension
    dim=length(value);
    %get result of guard events
    for i=1:length(obj.transition)
        %check if guard is a halfspace
        if isa(get(obj.transition{i},'guard'),'halfspace') ||...
           isa(get(obj.transition{i},'guard'),'constrainedHyperplane')
            [value(end+1),isterminal(end+1),direction(end+1)] = ...
                eventFcn(obj.transition{i},x);
        else
            indices=(i*dim+1):((i+1)*dim);
            [value(indices),isterminal(indices),direction(indices)] = ...
                eventFcn(obj.transition{i},x);
        end
    end
end

%return function handle
handle = @f;

end

%------------- END OF CODE --------------