function [obj,t,x,index] = simulate(obj,opt,tstart,tfinal,x0,options)
% simulate - simulates the linear interval system within a location
%
% Syntax:  
%    [t,x,index] = simulate(obj,tstart,tfinal,x0,options)
%
% Inputs:
%    obj - linIntSys object
%    tstart - start time
%    tfinal - final time
%    x0 - initial state 
%    options - contains, e.g. the events when a guard is hit
%
% Outputs:
%    obj - linIntSys object
%    t - time vector
%    x - state vector
%    index - returns the event which has been detected
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author: Matthias Althoff
% Written: 16-May-2007 
% Last update: 07-January-2009
% Last revision: ---

%------------- BEGIN CODE --------------

%sample system matrix
obj=sample(obj);

[t,x,te,xe,index] = ode45(getfcn(obj,opt),[tstart, tfinal],x0,options);
    
% %get input changes
% inputChanges=opt.inputChanges;
% 
% %obtain time interval with constant input
% constInputInterval=tfinal/inputChanges;
% 
% %initialize simulation results
% tstartTmp=0;
% tfinalTmp=constInputInterval;
% index=[];
% x=[];
% t=[];
% 
% %simulate for constant input time intervals:
% while isempty(index) & (tstartTmp<tfinal)
%     
%     %randomize input
%     opt.u=randPoint(opt.U);
%     
%     %sample system matrix
%     obj=sample(obj);
%     
%     %simulate
%     [tTmp,xTmp,te,xe,index] = ode45(getfcn(obj,opt),[tstartTmp, tfinalTmp],x0,options);
%     
%     %add simulation results
%     x=[x;xTmp];
%     t=[t;tTmp];
% 
%     
%     %update times/initial value
%     tstartTmp=t(end);
%     tfinalTmp=t(end)+constInputInterval;
%     x0=xTmp(end,:);
% end



% only for random sample generation
% 
% %if simulation has finished:
% %compute new sample values
% if t(end)==tfinal
%     obj=sample(obj);
% end
    
%------------- END OF CODE --------------