function [Rerror] = errorSolution(obj,error,options)
% errorSolution - computes the solution due to the linearization error
%
% Syntax:  
%    [Rerror] = errorSolution(linSys,options)
%
% Inputs:
%    obj - linear system object
%    nonlinSys - nonlinear system object
%    options - options struct
%
% Outputs:
%    Rerror - reachable set due to the linearization error
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: ---

% Author: Matthias Althoff
% Written: 18-January-2008 
% Last update: ---
% Last revision: ---

%------------- BEGIN CODE --------------

%load data from object/options structure
Apower=obj.taylor.powers;
V=zonotope(intervalhull([-error,error]));
E=obj.taylor.error;
taylorTerms=options.taylorTerms;
r=options.timeStep;
dim=dimension(obj);

%initialize Asum
Asum=eye(dim)*r*V;

for i=1:taylorTerms
    %compute powers
    ApowerV{i}=Apower{i}*V;
    %compute factor
    factor=1/(factorial(i)*(i+1));    
    %compute sums
    Asum=Asum+ApowerV{i}*factor*r^(i+1);
end

%get error due to finite Taylor series
F=E*V*r;

%Compute error solution
Rerror=Asum+F;

%Convert to zonotope if inputSol is an interval hull
if strcmp('interval',class(Rerror))
    Rerror=zonotope(intervalhull([inf(Rerror),sup(Rerror)]));
end

%------------- END OF CODE --------------