function A = uniformSampling(obj,segments)
% uniformSampling - uniformly samples the system interval matrix
%
% Syntax:  
%    [obj] = sample(obj,segments)
%
% Inputs:
%    obj - linIntSys object
%    segments - number of segments for each uncertain element
%
% Outputs:
%    A - cell array of system matrices
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author: Matthias Althoff
% Written: 06-May-2009 
% Last update: ---
% Last revision: ---

%------------- BEGIN CODE --------------

%number of uncertain parameters
nrOfParam=length(obj.A)^2;

%obtain parameter values of the uncertain interval
paramValues=linspace(-1,1,segments);

%obtain full factorial combinations of uncertain parameters
comb=fullfact(segments*ones(nrOfParam,1));

%obtain middle of A
midA=mid(obj.A);
deltaA=sup(obj.A)-midA;

%generate sample matrices
for i=1:length(comb(:,1))
    %init A{i}
    A{i}=midA;
    for k=1:nrOfParam
        %create uncertain parameter vector
        paramVal=paramValues(comb(i,k));
        %add partial matrix
        A{i}(k)=A{i}(k)+paramVal*deltaA(k);
    end
end

    
%------------- END OF CODE --------------