classdef linParamSys
% linParamSys class (linear parametric system; parameters are constant over time)
%
% Syntax:  
%    object constructor: Obj = linParamSys(varargin)
%    copy constructor: Obj = otherObj
%
% Inputs:
%    A - system matrix
%    B - input matrix
%    stepSize - time increment
%    taylorTerms - number of considered Taylor terms
%
% Outputs:
%    Obj - Generated Object
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: ---

% Author:       Matthias Althoff
% Written:      23-September-2010
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------
  

properties (SetAccess = private, GetAccess = public)
    A = 1;
    B = 0;
    %stepSize = 0.01/max(abs(eig(A.center)));
    stepSize = 1;
    taylorTerms = [];
    dim = 1;
    mappingMatrixSet = [];
    power = [];
    E = [];
    F = [];
    inputF = [];
    inputCorr = [];
    Rinput = [];
    Rtrans = [];
    RV = [];
    sampleMatrix = [];
end
    
methods
    %class constructor
    function obj = linParamSys(A,B,stepSize,taylorTerms)

        %one input
        if nargin==1
            obj.dim = A.dim;
            obj.A = A;
        %two inputs
        elseif nargin==2
            obj.dim = A.dim;
            obj.A = A;
            obj.B = B;
        %three inputs
        elseif nargin==3
            obj.dim = A.dim;
            obj.A = A;
            obj.B = B;
            obj.stepSize = stepSize;
        %four inputs
        elseif nargin==4
            obj.dim = A.dim;
            obj.A = A;
            obj.B = B;
            obj.stepSize = stepSize;
            obj.taylorTerms = taylorTerms;
        end 
        
        tmp = uniformSampling(obj.A,1);
        obj.sampleMatrix.A = tmp{1};
    end
         
    %methods in seperate files 
    [obj,Rfirst,options] = initReach(obj, Rinit, options)
    [Rnext,options] = reach(obj,R,options)
    [obj] = preReach(obj,options)
    [Rfirst] = coreReach(obj,Rinit,options)
    [Rnext,IH] = postReach(obj,Rinit,R_tp,c)
    [obj,t,x,index] = simulate(obj,opt,tstart,tfinal,x0,options)
    handle = getfcn(obj,options)
    
    %display functions
    plot(varargin)
    display(obj)
end
end

%------------- END OF CODE --------------