function [Rnext,options] = reach(obj,R,options)
% reach - computes the reachable continuous set for one time step of a
% linear interval system
%
% Syntax:  
%    [Rnext] = reach(obj,R,options)
%
% Inputs:
%    obj - linIntSys object
%    R - reachable set of the previous time step
%    options - options for the computation of the reachable set
%
% Outputs:
%    Rnext - reachable set of the next time step
%    options - options for the computation of the reachable set
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author:       Matthias Althoff
% Written:      15-May-2007 
% Last update:  07-January-2009
%               22-June-2009
%               29-June-2009
%               06-August-2010
% Last revision: ---

%------------- BEGIN CODE --------------

%next set (no input)
M1 = obj.mappingMatrixSet.zono;
M2 = obj.mappingMatrixSet.int;
R.ti = M1*R.ti + M2*R.ti; 

%bloating due to input
R.ti = R.ti + obj.Rinput;

%reduce zonotope
Rred=reduce(R.ti,'girard',options.zonotopeOrder);

% %reduce zonotope
% dim = M2.dim;
% filterLength(1) = dim+2;
% filterLength(2) = dim+1;
% Rred=reduce(R.ti,'althoff',options.zonotopeOrder,filterLength);

%reduce zonotope
%Rred=options.T*reduce(options.T'*R.ti,'girard',options.zonotopeOrder);

% %Zmapped
% eAtPrep=expm(options.Acenter*options.t)+diag(1e-6*ones(length(options.eAt),1));
% %eAtPrep=expm(options.Acenter*options.t);
% W=pinv(eAtPrep);
% Zmapped = W*R.ti;
% %Rred=reduce(Zmapped,'combastel',options.zonotopeOrder);
% Rred=reduce(Zmapped,'girard',options.zonotopeOrder);
% Rred=eAtPrep*Rred;


%write results to reachable set struct Rnext
Rnext.tp=[];
Rnext.ti=Rred;


%------------- END OF CODE --------------