function createJacobianFile_input(obj)
% createJacobianFile - generates an mFile that allows to compute the
% jacobian at a certain state and input
%
% Syntax:  
%    createJacobianFile(obj)
%
% Inputs:
%    obj - nonlinear parametric system object
%
% Outputs:
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: ---

% Author:       Matthias Althoff
% Written:      27-May-2011
% Last update:  ---
% Last revision: ---

%------------- BEGIN CODE --------------

%load jacobian
J=obj.J.u;
%create symbolic variables
[x,u,y] = symVariables(obj,'LRbrackets');

%store in stateSpaceModels folder
cd('/media/New Volume/software/2011/CORA/contDynamics/stateSpaceModels') %<-- change directory here

fid = fopen('jacobian_vehicleFull_input.m','w');
fprintf(fid, '%s\n\n', 'function B=jacobian_vehicleFull_input(x,u,y)');


% INPUT MATRIX
% write "B=["
fprintf(fid, '%s', 'B=[');

%write each row
for iRow=1:(length(J(:,1)))
    if length(J(1,:))>1
        for iCol=1:(length(J(1,:))-1)
            str=[char(J(iRow,iCol)),','];
            str=bracketSubs(str);
            %write in file
            fprintf(fid, '%s', str);
        end
    else iCol=0;
    end
    
    if iRow<length(J(:,1))
        %write last element
        str=[char(J(iRow,iCol+1)),';...'];
        str=bracketSubs(str);
        %write in file
        fprintf(fid, '%s\n', str);    
    else
        %write last element
        str=[char(J(iRow,iCol+1)),'];']; 
        str=bracketSubs(str);
        %write in file
        fprintf(fid, '%s', str);
    end
end


%close file
status = fclose(fid);

function [str]=bracketSubs(str)

%generate left and right brackets
str=strrep(str,'L','(');
str=strrep(str,'R',')');
    


%------------- END OF CODE --------------