function [IH] = intervalhull(V)
% intervalhull - Encloses a point set by an interval hull
%
% Syntax:  
%    [IH] = intervalhull(V)
%
% Inputs:
%    V - vertices object
%
% Outputs:
%    IH - intervalhull object
%
% Example: 
%
% Other m-files required: intervalhull(constructor)
% Subfunctions: none
% MAT-files required: none
%
% See also: vertices, polytope

% Author:       Matthias Althoff
% Written:      29-October-2007
% Last update:  13-December-2010
% Last revision:---

%------------- BEGIN CODE --------------

%if vertices object is nonempty
if ~isempty(V.V)
    %minimum values
    leftLimit=min(V.V,[],2);

    %maximum values
    rightLimit=max(V.V,[],2);

    %instantiate interval hull
    IH=intervalhull([leftLimit,rightLimit]);
else
    IH=[];
end


%------------- END OF CODE --------------