function [P] = newPolytope(Z)
% newPolytope - Converts a zonotope from a G- to a H-representation
%
% Syntax:  
%    [P] = newPolytope(Z)
%
% Inputs:
%    Z - zonotope object
%
% Outputs:
%    P - polytope object
%
% Example: 
%    Z=zonotope(rand(2,5));
%    P=polytope(Z);
%    plot(P);
%    hold on
%    plot(Z);
%
% Other m-files required: vertices, polytope
% Subfunctions: none
% MAT-files required: none
%
% See also: intervalhull,  vertices

% Author:       Matthias Althoff
% Written:      30-September-2008
% Last update:  26-February-2009
%               05-July-2010
%               20-October-2010
%               03-December-2010
%               02-September-2011 (delete aligned added)
% Last revision:---

%------------- BEGIN CODE --------------


%obtain number of generators, dimensions
%Z=deleteAligned(Z);
Z=deleteZeros(Z);
c=Z.Z(:,1);
G=Z.Z(:,2:end);
[dim,nrOfGenerators]=size(G);

%get number of possible facets
%comb=combnk(1:nrOfGenerators,dim-1);
comb=combinator(nrOfGenerators,dim-1,'c');

%build C matrices
C=[];
for i=1:length(comb(:,1))
    indices=comb(i,:);
    Q=G(:,indices);
    v=ndimCross(Q);
    C(end+1,:)=v'/norm(v);
end

%remove NaN rows due to rank deficiency
index = find(sum(isnan(C),2));
if ~isempty(index)
    C(index,:) = [];
end

%build d vector
for i=1:length(C(:,1))

    %determine delta d
    deltaD=0;
    for iGen=1:nrOfGenerators
        deltaD=deltaD+abs(C(i,:)*G(:,iGen));
    end

    %compute dPos, dNeg
    dPos(i,1)=C(i,:)*c+deltaD;
    dNeg(i,1)=-C(i,:)*c+deltaD;
end

P=pplPolytope([C;-C],[dPos;dNeg]);

%------------- END OF CODE --------------