function [P] = normalVecToGenerators(Z)
% newPolytope - Converts a zonotope from a G- to a H-representation
%
% Syntax:  
%    [P] = newPolytope(Z)
%
% Inputs:
%    Z - zonotope object
%
% Outputs:
%    P - polytope object
%
% Example: 
%    Z=zonotope(rand(2,5));
%    P=polytope(Z);
%    plot(P);
%    hold on
%    plot(Z);
%
% Other m-files required: vertices, polytope
% Subfunctions: none
% MAT-files required: none
%
% See also: intervalhull,  vertices

% Author: Matthias Althoff
% Written: 01-April-2010
% Last update: ---
% Last revision: ---

%------------- BEGIN CODE --------------


%obtain number of generators, dimensions
c=Z.Z(:,1);
G=Z.Z(:,2:end);
[G]=nonzeroFilter(G);
[dim,nrOfGenerators]=size(G);

%normalize G
for i=1:length(G(1,:))
    G(:,i)=G(:,i)/norm(G(:,i));
end

%get number of possible facets
comb=combnk(1:nrOfGenerators,dim-1);

%build C matrices
for i=1:length(comb(:,1))
    indices=comb(i,:);
    Q=G(:,indices);
    v=ndimCross(Q);
    C(i,:)=v'/norm(v);
end

createGeneratorEquations(dim);



%------------- END OF CODE --------------