function plot(varargin)
% plot - Plots 2-dimensional projection of a zonotope
%
% Syntax:  
%    plot(Z,dimensions)
%
% Inputs:
%    Z - zonotope object
%    dimensions - dimensions that should be projected (optional) 
%
% Outputs:
%    none
%
% Example: 
%    Z=zonotope([1 1 0; 0 0 1]);
%    plot(Z)
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author: Matthias Althoff
% Written: 30-September-2006 
% Last update: 22-March-2007
% Last revision: ---

%------------- BEGIN CODE --------------

%If only one argument is passed
if nargin==1
    Z=varargin{1};
    dimensions=[1,2];
    type='frame';
    
%If two arguments are passed    
elseif nargin==2
    Z=varargin{1};
    dimensions=varargin{2};
    type='frame';
    
%If too many arguments are passed
elseif nargin==3
    Z=varargin{1};
    dimensions=varargin{2};   
    type=varargin{3};
end

%delete zero generators
Z=deleteZeros(Z);
    
%Compute potential vertices
V=vertices(Z,dimensions);
%Plot convex hull of projected vertices
plot(V,type);

%------------- END OF CODE --------------