function [Pred,t]=reduceMethFa(Z)
% reduceMethD - like method D, but computes the exact volume directly
%
% Syntax:  
%    [Pred]=reduceMethD(Z)
%
% Inputs:
%    Z - zonotope object
%
% Outputs:
%    Pred - polytope of reduced zonotope
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: 

% Author: Matthias Althoff
% Written: 11-September-2008
% Last update: ---
% Last revision: ---

%------------- BEGIN CODE --------------

tic;

%get Z-matrix from zonotope Z
Zmatrix=get(Z,'Z');
dim=length(Zmatrix(:,1));

%extract generator matrix
G=Zmatrix(:,2:end);

%Delete zero-generators
G=nonzeroFilter(G);

%determine filter length
filterLength=dim+8;
if filterLength>length(G(1,:))
    filterLength=length(G(1,:));
end

%length filter
G=lengthFilter(G,filterLength);

%reorder generators
Gcells=reorderingFilter(G);

%pick generator with the best volume
Gtemp=volumeFilter(Gcells,Z);
Gpicked=Gtemp{1};

%Build transformation matrix P
for i=1:dim
    P(:,i)=Gpicked(:,i);
end

%Project Zonotope into new coordinate system
Ztrans=inv(P)*Z;
Zintervalhull=intervalhull(Ztrans);
Zred=P*zonotope(Zintervalhull);

%generate polytopes
Pred=parallelpiped(Zred);

%time measurement
t=toc;

%t=Zred; %<--Change here!!

%------------- END OF CODE --------------
