function [Zquad] = quadraticMultiplication_old2(Z,Q)
% quadraticMultiplication - computes \{Q_{ijk}*x_j*x_k|x \in Z\}
%
% Syntax:  
%    [Zquad] = quadraticMultiplication(Z1,Q)
%
% Inputs:
%    Z - zonotope object
%    Q - quadratic coefficients as a cell of matrices
%
% Outputs:
%    Zquad - zonotope object
%
% Example: 
%    ---
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author:       Matthias Althoff
% Written:      07-December-2011
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------


%get matrix of zonotope
Zmat = get(Z,'Z');
dim = length(Q);
gens = length(Zmat(1,:)) - 1;

%for each dimension, compute generator elements
for i = 1:dim
    
    %pure quadratic evaluation
    quadMat = Zmat'*Q{i}*Zmat;
    
    %center
    c(i,1) = quadMat(1,1) + 0.5*sum(diag(quadMat(2:end,2:end)));
    
    %generators with center
%     for j = 1:gens
%         G(i,j) = quadMat(1,j+1) + quadMat(j+1,1);
%     end
    ind = 1:gens;
    G(i,ind) = quadMat(1,ind+1) + quadMat(ind+1,1)'; 
    
    %generators from diagonal elements
    for j = 1:gens
        G(i, gens + j) = 0.5*quadMat(j+1,j+1);
    end
    
    %generators from other elements
    counter = 1;
    for j = 1:gens
        for k = (j+1):gens
            G(i, 2*gens + counter) = quadMat(j+1, k+1) + quadMat(k+1, j+1);
            counter = counter + 1;
        end
    end
    
end

%generate new zonotope
Zquad = zonotope([c, G]);


%------------- END OF CODE --------------