function [Zsplit] = split(Zbundle,options,varargin)
% split - Splits a zonotope bundle into two zonotope bundles. This is done 
% for one or every generator resulting in n possible splits where n is the 
% system dimension
%
% Syntax:  
%    [Zsplit] = split(Zbundle)
%
% Inputs:
%    Z - zonotope bundle
%    options - computation options
%    
%
% Outputs:
%    Zsplit - one or many zonotope bundle pairs
%
% Example: 
%    ---
%
% Other m-files required: reduce
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author:       Matthias Althoff
% Written:      03-February-2011
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------

%initialize
all=1;
if nargin==3
    dim=varargin{1};
    all=0; 
end

%obtain enclosing interval hull
IH = intervalhull(Zbundle);
%obtain limits
leftLimit = IH(:,1);
rightLimit = IH(:,2);


if all
    for dim = 1:length(leftLimit)
        %split one dimension of the interval hull
        Zsplit{dim} = splitOneDim(Zbundle,leftLimit,rightLimit,options,dim); 
    end
else
    %split one dimension
    Zsplit = splitOneDim(Zbundle,leftLimit,rightLimit,options,dim);  
end


function Zsplit=splitOneDim(Zbundle,leftLimit,rightLimit,options,dim)


%split limits for a given dimension
leftLimitMod = leftLimit;
leftLimitMod(dim) = 0.5*(leftLimit(dim)+rightLimit(dim));
rightLimitMod = rightLimit;
rightLimitMod(dim) = 0.5*(leftLimit(dim)+rightLimit(dim));

%construct zonotopes which are the left and right boxes
Zleft = zonotope(intervalhull([leftLimit,rightLimitMod]));
Zright = zonotope(intervalhull([leftLimitMod,rightLimit]));

%generate splitted zonotope bundles
Zsplit{1} = Zbundle & Zleft;
Zsplit{2} = Zbundle & Zright;   

%shrink zonotopes
W{1} = eye(length(options.W));
% Zred = reduce(Zbundle.Z{1},'methC',1,options.filterLength);
% Zmat = get(Zred,'Z');
% W{2} = Zmat(:,2:end); %<-- obtain this from order reduction!!

% Zsplit{1} = Zbundle & shrink2(Zsplit{1},W);
% Zsplit{2} = Zbundle & shrink2(Zsplit{2},W);

% Zsplit{1} = pinv(options.W)*shrink(options.W*Zsplit{1},options.filterLength);
% Zsplit{2} = pinv(options.W)*shrink(options.W*Zsplit{2},options.filterLength);

%------------- END OF CODE --------------