function [eAt] = expOld(A)
% expm - computes the exponential of an interval matrix defined by a linear
% interval system object; type specifies if over- or underapproximation
% should be computed
%
% Syntax:  
%    [obj] = expm(obj)
%
% Inputs:
%    obj - linear interval system object
%    type - 'under' or 'over' for over- or underapproximation; default:
%    type='over'
%
% Outputs:
%    obj - linear interval system object
%
% Example: 
%    Text for example...
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: OTHER_FUNCTION_NAME1,  OTHER_FUNCTION_NAME2

% Author: Matthias Althoff
% Written: 19-April-2010
% Last update: ---
% Last revision: ---

%------------- BEGIN CODE --------------

    
%load data from object/options structure
taylorTerms=10;

dim=length(mid(A));
r=1;

%initialize overapproximation
Apower{1}=A;

[H,Asquare] = exactTerms(A);

Asum=H+eye(dim);    

%compute powers for each term and sum of these
for i=1:taylorTerms
    %compute powers
    if i==1
        Apower{2}=Asquare;
    else
        Apower{i+1}=Apower{i}*A;
    end

    if i>=3
        %compute sums
        Asum=Asum+Apower{i}*r^i/factorial(i);
    end
end   
%determine error due to finite Taylor series
alpha=infNorm(A);
epsilon=alpha*r/(taylorTerms+2);
phi=(alpha*r)^(taylorTerms+1)/factorial(taylorTerms+1)/(1-epsilon);
E=interval(-ones(dim),ones(dim))*phi;

%write to object structure
eAt=Asum+E;
  

%--------------------------------------------------------------------------

function n=infNorm(A)
    n=norm(abs(A),inf);


function [H,sq] = exactTerms(A)

%load data from object structure
r=1;
dim=length(mid(A));

%initialize the square of A (sq), the first term of the interval exponential (H), the
%first term of the exponential for the input (Hu)
sq=0*A;
H=0*A;
Hu=0*A;
E=eye(dim); %identity matrix

%get diagonal elements of A (diagA)
for i=1:dim
    diagA(i,i)=A(i,i);
end

%compute elements of H, Hu and sq
for i=1:dim
    %i neq j
    %auxiliary value s
    s=sum(A,i);
    %auxiliary value b
    b=A(i,:); b(i)=0;
    %auxiliary matrix C
    C=E*A(i,i)+diagA;
    %compute non-diagonal elements of sq
    sq(i,:)=b*C+s;
    %compute non-diagonal elements of H
    H(i,:)=b*(E*r+0.5*C*r^2)+0.5*r^2*s;
    %compute non-diagonal elements of Hu
    Hu(i,:)=b*(0.5*E*r^2+1/6*C*r^3)+1/6*r^3*s;  
    
    %i=j
    %compute diagonal elements of sq
    sq(i,i)=sq(i,i)+A(i,i)^2;            
    %auxiliary values for H, Hu
    a_inf=inf(A(i,i));
    a_sup=sup(A(i,i));
    %compute diagonal elements for H
    kappa=max(a_inf*r+0.5*a_inf^2*r^2,a_sup*r+0.5*a_sup^2*r^2);
    H(i,i)=H(i,i)+interval(g(A(i,i),r),kappa);
    %compute diagonal elements for Hu
    kappa_u=max(0.5*a_inf*r^2+1/6*a_inf^2*r^3,0.5*a_sup*r^2+1/6*a_sup^2*r^3);
    Hu(i,i)=Hu(i,i)+interval(gu(A(i,i),r),kappa_u);            
    %--------------------------------------------------------------
end

%write results to object structure
obj.taylor.sq=sq;
obj.taylor.H=H;
obj.taylor.Hu=Hu;

%auxiliary function g()
function [res]=g(a,r)
    if in(interval(-1/r),a)
        res=-0.5;
    else
        a_inf=inf(a);
        a_sup=sup(a);
        res=min(a_inf*r+0.5*a_inf^2*r^2,a_sup*r+0.5*a_sup^2*r^2);
    end
    
%auxiliary function gu()
function [res]=gu(a,r)
    if in(interval(-3/(2*r)),a)
        res=-9/24*r;
    else
        a_inf=inf(a);
        a_sup=sup(a);
        res=min(0.5*a_inf*r^2+1/6*a_inf^2*r^3,0.5*a_sup*r^2+1/6*a_sup^2*r^3);
    end    

%sum function:
%s=0.5 \sum_{k:k\neq i,k\neq j} a_{ik}a_{kj}t^2
function s=sum(A,i)

% for k=1:length(A)
%     A(k,k)=0;
% end
%get indices that should be 0
n=length(A);
k=0:n;
ind=k*n+1:n+1:n^2;
A(ind)=zeros(n,1);

s=A(i,:)*A;


%------------- END OF CODE --------------