function twoDimInt07()

%set options --------------------------------------------------------------
options.tStart=0; %start time
options.tFinal=5; %final time
options.x0=[1; 1]; %initial state for simulation
options.R0=zonotope([options.x0,0.1*eye(length(options.x0))]); %initial state for reachability analysis
options.startLoc=1; %initial location
options.finalLoc=0; %final location
options.timeStep=0.04; %time step size for reachable set computation
%options.taylorTerms=4; %number of taylor terms for reachable sets
options.taylorTerms=8; %number of taylor terms for reachable sets
options.zonotopeOrder=10; %zonotope order
options.polytopeOrder=2; %polytope order
options.projectedDimensions=[1 2];
options.plotType='blackFrame';
options.isHybrid=0;
options.originContained=1;

uTrans=0;
options.uLoc{1}=[uTrans]; %input for simulation
%options.Uloc{1}=zonotope([0,0.1]); %input for reachability analysis
options.Uloc{1}=zonotope([0,0]); %input for reachability analysis
%options.Uloc{1}=zonotope(0); %input for reachability analysis
options.uLocTrans{1}=uTrans; %origin is contained
%--------------------------------------------------------------------------

%specify continuous dynamics-----------------------------------------------
Anom=[-1 -4; 4 -1];
%Adiff=[0.1 0.1; 0.1 0.1];
Adiff=2*[0.1 0.1; 0.1 0.1];
%Adiff=[0 0; 0 0];
A=interval(Anom-Adiff,Anom+Adiff);
deltaA=interval(-Adiff,Adiff);
Anom=interval(Anom);

twoDimSys=linIntSys07('twoDimSys',A,[1;1]); %initialize linear interval system
twoDimSysNom=linIntSys07('twoDimSys',Anom,[1;1]); %initialize linear interval system
%--------------------------------------------------------------------------

%specify transitions-------------------------------------------------------
%reset map for all transitions
reset.A=eye(2); 
reset.b=zeros(2,1);

%long distance l
l1=[1e3 2e3];
l2=[-1e3 1e3];

%specify invariant
inv=intervalhull([l2; l2]); %invariant for all locations

%guard sets
IHdummy=intervalhull([l1; l1]);                            

%specify transitions
tran1{1}=transition(IHdummy,reset,2,'a','b'); 
%--------------------------------------------------------------------------

%OVERALL SYSTEM
%specify locations              
loc{1}=location('loc1',inv,tran1,twoDimSys);
%specify hybrid automaton
HA=hybridAutomaton(loc);

%NOMINAL SYSTEM
%specify locations              
loc{1}=location('loc1',inv,tran1,twoDimSysNom);
%specify hybrid automaton
HAnom=hybridAutomaton(loc);


%compute reachable set
[HA,Rtotal]=reach(HA,options);
[HAnom,Rtotal]=reach(HAnom,options);

%get fast enclosure
R=fastEnclosure(HAnom,Anom,deltaA,options);

%obtain random simulation results
for i=1:30
    %set initial state, input
    if i<=15
        options.x0=randPointExtreme(options.R0); %initial state for simulation
    else
        options.x0=randPoint(options.R0); %initial state for simulation
    end
    if i<=8
        options.uLoc{1}=randPointExtreme(options.Uloc{1})+options.uLocTrans{1}; %input for simulation
    else
        options.uLoc{1}=randPoint(options.Uloc{1})+options.uLocTrans{1}; %input for simulation
    end
    
    %simulate hybrid automaton
    HAsim{i}=simulate(HA,options);      
end

figure;

%plot over-approximation
for i=1:length(R)
    plot(R{i},[1 2],'gray');
end

%plot simulation results      
for i=1:length(HAsim)
    plot(HAsim{i},'simulation',options);
end

%plot reachable sets
plot(HA,'reachableSet',options);

%plot initial set
plot(options.R0,options.projectedDimensions,'blackFrame');
