function val = expmNormErr(intMat,t)
% expmNorm - returns the over-approximation of the norm of the error for
% the computation of the mapping mimicing the exponential
%
% Syntax:  
%     val = expmNormErr(intMat,t)
%
% Inputs:
%    intMat - interval matrix
%    t - time
%
% Outputs:
%    val - value of the norm
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: plus

% Author:       Matthias Althoff
% Written:      25-June-2010 
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------

%extract nominal matrix and symmetric interval matrix
infA = inf(intMat.int);
supA = sup(intMat.int);
A = 0.5*(supA+infA);
S = 0.5*(supA-infA);

%set starting order
j=3;

%derive norm values
nA = norm(A);
nA2 = norm(A^2);
nS = norm(S);
nAS = norm(abs(A) + S);
M2 = norm((abs(A)+S)*S + S*abs(A));

%compute summand1
summand1 = nA2*nS*t^3/(2*j)/(nA*nAS*t^2/j^2 - (nA+nAS)*t/j + 1);
summand2 = M2*t^2/2/(1 - nAS*t/j);

%final result
val = summand1 + summand2;

%Tests-----------------------------------
%build G matrix
G = [nA*t/j 0 0;...
     nS*t/j nAS*t/j 0;...
     0 1 1];
 
 %compute approximated Ginf
 Ginf = G^100;
 
 %set initial vector
 initVec = [nA2*t^2/2; M2*t^2/2; 0];
 
 %final result
 val2 = [0 0 1]*Ginf*initVec;

%------------- END OF CODE --------------