function dist = expmDist(intMat,exactMat,maxOrder)
% expmDist - computes an over-approximated Hausdorff distance between an 
% exponential matrix that is evaluated independently compared to the exact
% solution
%
% Syntax:  
%    dist = expmDist(intMat,exactMat,maxOrder)
%
% Inputs:
%    intMat - interval matrix
%    exactMat - matrix set representing the exact uncertain matrix A
%    maxOrder - maximum Taylor series order until remainder is computed
%
% Outputs:
%    dist - over-approximated Hausdorff distance
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: plus

% Author:       Matthias Althoff
% Written:      23-June-2010 
% Last update:  24-June-2010
% Last revision:---

%------------- BEGIN CODE --------------

%COMPUTE OVER_APPROXIMATION-------------
%compute finite Taylor series starting at second order
%initialize matrix zonotope
eI=intervalMatrix(zeros(intMat.dim));
%initialize power
eIpow=intMat;

%compute powers
for i=1:maxOrder
    eIpow = eIpow*intMat;
    eI = eI + eIpow*(1/factorial(i));
end

%compute exponential remainder
E = exponentialRemainder(intMat,maxOrder);

%final result: add twice the exponential remainder
eIset = eI+2*E;
%----------------------------------------

%COMPUTE EXEMPLARY SOLUTIONS-------------
%get solutions from vertices of the uncertain system matrix
A=vertices(exactMat);

eSset=cell(length(A),1); %S: sample
for iSample=1:length(A)
    eS=zeros(exactMat.dim);
    %initialize power
    eSpow=A{iSample};
    %compute powers
    for i=1:maxOrder
        eSpow = eSpow*A{iSample};
        eS = eS + eSpow*(1/factorial(i));
    end
    %save result
    eSset{iSample}=eS;
end
%----------------------------------------

%compute the Hausdorff distance
dist=Hausdorff(eIset,eSset);

%------------- END OF CODE --------------