function dist = expmDist(matP,exactMat,maxOrder)
% expmDist - computes an over-approximated Hausdorff distance between an 
% exponential matrix that is evaluated independently compared to the exact
% solution
%
% Syntax:  
%    dist = expmDist(matP,exactMat,maxOrder)
%
% Inputs:
%    matP - matrix polytope
%    exactMat - matrix set representing the exact uncertain matrix A
%    maxOrder - maximum Taylor series order until remainder is computed
%
% Outputs:
%    dist - over-approximated Hausdorff distance
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: plus

% Author:       Matthias Althoff
% Written:      24-June-2010 
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------

%COMPUTE OVER_APPROXIMATION-------------
%compute finite Taylor series starting at second order
%initialize matrix polytope
V{1}=zeros(matP.dim);
eP=matPolytope(V);
%initialize power
ePpow=matP;

%compute powers
for i=1:maxOrder
    ePpow = ePpow*matP;
    eP = eP + ePpow*(1/factorial(i));
end

%create over-approximating interval matrix
intMat = intervalMatrix(matP);
%compute exponential remainder
E = exponentialRemainder(intMat,maxOrder);

%final result: add twice the exponential remainder
ePset = eP+2*E;
%----------------------------------------

%COMPUTE EXEMPLARY SOLUTIONS-------------
%get solutions from vertices of the uncertain system matrix
A=vertices(exactMat);

eSset=cell(length(A),1); %S: sample
for iSample=1:length(A)
    eS=zeros(exactMat.dim);
    %initialize power
    eSpow=A{iSample};
    %compute powers
    for i=1:maxOrder
        eSpow = eSpow*A{iSample};
        eS = eS + eSpow*(1/factorial(i));
    end
    %save result
    eSset{iSample}=eS;
end
%----------------------------------------

%compute the Hausdorff distance
dist=Hausdorff(ePset,eSset);

%------------- END OF CODE --------------