function plotComb(varargin)
% plotComb - Plots 2-dimensional projection of the Minkowski addition of a 
% matrix polytope with an interval matrix
%
% Syntax:  
%    plotComb(varargin)
%
% Inputs:
%    obj - matrix polytope
%    intMat - interval matrix
%    dimensions - dimensions that should be projected (optional) 
%    linespec - plot style (optional) 
%
% Outputs:
%    none
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author:       Matthias Althoff
% Written:      22-June-2010
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------

%plot vertices
if nargin==2
    matP=varargin{1};
    intMat=varargin{2};
    dims=[1 2];
    style='b-';
elseif nargin==3
    matP=varargin{1};
    intMat=varargin{2};
    dims=varargin{3};
    style='b-';
elseif nargin==4
    matP=varargin{1};
    intMat=varargin{2};
    dims=varargin{3};
    style=varargin{4};
end

%convert vertices of matrix polytope
for i=1:matP.verts
    vec=mat2vec(matP.vertex{i});
    V(i,:)=vec(dims);
end
%keep only unique vertices
V = unique(V, 'rows');

%instantiate polytope with less dimensions
Pproj = polytope(V);

%project interval matrix
IH = intervalhull(intMat);
IHproj = intervalhull(IH(dims,:));

%add projected interval matrix
Pproj = Pproj + polytope(IHproj);

%plot projection
V = extreme(Pproj);
V = vertices(V');
plot(V,style);

%------------- END OF CODE --------------