function [P] = twoDimHalfspace(Z)
% twoDimHalfspace - Converts a two-dimensional zonotope into halfspace
% representation
%
% Syntax:  
%    [P] = twoDimHalfspace(Z)
%
% Inputs:
%    Z - zonotope object
%
% Outputs:
%    P - polytope object
%
% Example: 
%
% Other m-files required: vertices, polytope
% Subfunctions: none
% MAT-files required: none
%
% See also: intervalhull,  vertices

% Author: Matthias Althoff
% Written: 15-September-2008
% Last update: ---
% Last revision: ---

%------------- BEGIN CODE --------------

%set dimension
dim=2;
%retrieve center of the zonotope
c=Z.Z(:,1);
%retrieve generator matrix G
G=Z.Z(:,2:end);
G=nonzeroFilter(G);
%get number of generators
nrOfGen=length(G(1,:));


%build C matrix
rotMatrix=[0 -1; 1 0];
for i=1:nrOfGen
    v=rotMatrix*G(:,i);
    C(i,:)=v'/norm(v);
end

%build d vector
%halfspace loop
for iHalfspace=1:nrOfGen
    %init
    dPos(iHalfspace,1)=C(iHalfspace,:)*c;
    dNeg(iHalfspace,1)=-C(iHalfspace,:)*c;
    %generator loop
    for iGen=1:nrOfGen
%         %determine direction
%         s=sign(C(iHalfspace,:)*G(:,i));
%         if s==0
%             s=1;
%         end
%         dPos(iHalfspace,1)=dPos(iHalfspace,1)+C(iHalfspace,:)*s*G(:,iGen);
%         dNeg(iHalfspace,1)=dNeg(iHalfspace,1)+C(iHalfspace,:)*s*G(:,iGen);  

          dPos(iHalfspace,1)=dPos(iHalfspace,1)+abs(C(iHalfspace,:)*G(:,iGen));
          dNeg(iHalfspace,1)=dNeg(iHalfspace,1)+abs(C(iHalfspace,:)*G(:,iGen));  

    end  
end

P=polytope([C;-C],[dPos;dNeg]);


%------------- END OF CODE --------------