function dist = Hausdorff(matSet,matrix)
% Hausdorff - computes the Hausdorff distance between a matrix set and
% a finite set of matrices
%
% Syntax:  
%    dist = Hausdorff(matSet,matrix)
%
% Inputs:
%    matSet - set of matrices
%    matrix - cell array of matrices
%
% Outputs:
%    dist - Hausdorff distance
%
% Example: 
%
% Other m-files required: vertices, polytope
% Subfunctions: none
% MAT-files required: none
%
% See also: ---

% Author:       Matthias Althoff
% Written:      23-June-2010
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------

%obtain vertices
V=vertices(matSet);
    
%compute distance between all vertices and all given matrices
minDist=ones(length(V),1)*inf;
for i=1:length(V)
    %find minimum distance for a given vertex in V
    for j=1:length(matrix)
        d=norm(V{i}-matrix{j});
        if d<minDist(i)
            minDist(i)=d;
        end
    end
end

%Hausdorff distance is maximum of minimum distances
dist=max(minDist);




%------------- END OF CODE --------------