function bouncingBall()
% updated: 31-January-2012, MA

dim=2;

%set options---------------------------------------------------------------
options.x0 = [1; 0]; %initial state for simulation
options.R0 = zonotope([options.x0, diag([0.05, 0.05])]); %initial state for reachability analysis
options.startLoc = 1; %initial location
options.finalLoc = 0; %0: no final location
options.tStart = 0; %start time
options.tFinal = 5; %final time
options.timeStepLoc{1} = 0.05; %time step size for reachable set computation in location 1

options.taylorTerms = 10;
options.zonotopeOrder = 20;
options.errorOrder=2;

options.isHybrid = 1;
options.originContained = 0;
%--------------------------------------------------------------------------

%obtain factors for initial state and input solution; this has to be hidden
%in the corresponding classes; future work
for i=1:(options.taylorTerms+1)
    r = options.timeStepLoc{1};
    options.factor(i)= r^(i)/factorial(i);    
end


%specify linear system of bouncing ball
A = [0 1; 0 0];
B = eye(dim); % no loss of generality to specify B as the identity matrix
linSys = linearSys('linearSys',A,B);


%define large and small distance
dist = 1e3;
eps = 1e-6;

%specify guard set as hyperplane (only used in approach "mapping")
% implement x<0
n = [1; 0];
d = 0;
h_unconstrained = halfspace(n,d); 

%combine with v<0
C = [0 1];
d = 0;
h = constrainedHyperplane(h_unconstrained, C, d);

%specify guard sets as intervalhulls (only used in approach "geometric
%intersection")
IH = intervalhull([- eps, 0; -dist, 0]);


%loc1:
%invariant
inv = intervalhull([-eps, dist; -dist, dist]);
%guard sets
guard = h; % for "mapping approach"
guard_noHP = IH; % for "geometric intersection"
%resets
reset.A = [0, 0; 0, -0.75];
reset.b = zeros(dim,1);
%transitions
trans{1} = transition(guard,reset,1,'a','b'); %--> next loc: 1; 'a', 'b' are dummies
trans_noHP{1} = transition(guard_noHP,reset,1,'a','b'); %--> next loc: 1; 'a', 'b' are dummies
%specify location
loc{1} = location('loc1',inv,trans,linSys); % for "mapping approach"
loc_noHP{1} = location('loc1',inv,trans_noHP,linSys); % for "geometric intersection"


%specify hybrid automata
HA = hybridAutomaton(loc); % for "mapping approach"
HA_noHP = hybridAutomaton(loc_noHP); % for "geometric intersection"

%input:
%loc 1
options.uLoc{1} = [0; -1]; %input for simulation
options.uLocTrans{1} = options.uLoc{1}; %input center for reachability analysis
options.Uloc{1} = zonotope(zeros(dim,1)); %input deviation for reachability analysis


%obtain random simulation results------------------------------------------
for i=1:10
    %set initial state, input
    if i <= 5
        options.x0 = randPointExtreme(options.R0); %initial state for simulation
    else
        options.x0 = randPoint(options.R0); %initial state for simulation
    end 
    
    %simulate hybrid automaton
    HAsim = simulate(HA,options); 
    simRes{i} = get(HAsim,'trajectory');
end
%--------------------------------------------------------------------------

%compute reachable set-----------------------------------------------------
%mapping approach
tStart=tic;
options.isHyperplaneMap = 1;
[HA] = reach(HA,options);
Rcont = get(HA,'reachableSet');
disp('Mapping Approach')
tElapsed=toc(tStart)

%geometrical approach
tStart=tic;
options.isHyperplaneMap = 0;
options.enclosureEnables = [5]; %choose enclosure method(s)
[HA_noHP, Rtotal] = reach(HA_noHP,options);
Rcont_noHP = get(HA_noHP,'reachableSet');
disp('geometric approach')
tElapsed=toc(tStart)
%--------------------------------------------------------------------------

    
%choose projection
options.projectedDimensions = [1 2];
    
%plot mapping approach-----------------------------------------------------
figure
hold on
%plot continuous reachable set
redOrder = 3;
%1st time interval
Rplot = Rcont.OT;
%Rplot_noHP = Rcont_noHP.OT;
for iMode = 1:length(Rplot)
    for iSet = 1:length(Rplot{iMode})
        plot(Rplot{iMode}{iSet},[1 2],'b');            
    end
end

%plot initial set
plot(options.R0,options.projectedDimensions,'blackFrame');

%plot simulation results
for n=1:length(simRes)
    for j=1:length(simRes{n}.x)
        %plot results
        plot(simRes{n}.x{j}(:,options.projectedDimensions(1)), simRes{n}.x{j}(:,options.projectedDimensions(2)),'k');
    end
end
%--------------------------------------------------------------------------


%plot geometric approach---------------------------------------------------
figure
hold on
%plot continuous reachable set
redOrder = 3;
%1st time interval
Rplot = Rcont_noHP.OT;
%Rplot_noHP = Rcont_noHP.OT;
for iMode = 1:length(Rplot)
    for iSet = 1:length(Rplot{iMode})
        plot(Rplot{iMode}{iSet},[1 2],'b');            
    end
end

%plot initial set
plot(options.R0,options.projectedDimensions,'blackFrame');

%plot simulation results
for n=1:length(simRes)
    for j=1:length(simRes{n}.x)
        %plot results
        plot(simRes{n}.x{j}(:,options.projectedDimensions(1)), simRes{n}.x{j}(:,options.projectedDimensions(2)),'k');
    end
end
%--------------------------------------------------------------------------

